
    #	Trek's End
    
    #	Impactor velocity calculation
    
    #	Given the required impact energy, diameter of
    #	impactor, and density, compute the velocity
    #	(neglecting relativistic effects) required
    #	to deliver that energy.  For story development
    #	purposes, the velocity is also given as a fraction
    #	of the speed of light and the time required to
    #	traverse the equatorial diameter of the Earth.
    
    #	If you're looking at this code and don't have
    #	the slightest idea what it's talking about, please
    #	see:
    #
    #	    http://www.fourmilab.ch/documents/treks-end/
    
    #	Designed and implemented by John Walker in July 2003
    #	This program is in the public domain.

    #	Energy released in impact, ergs:
    $Energy = 1e36;
    
    #	Diameter of impactor, metres:
    $Diameter = 5000;
    
    #	Density of impactor, g/cc:
    $Density = 3;
    
    #	Velocity of impactor, metres/second:
    $Velocity = 0;
    
    #	Constants

    $Pi = 3.14159265358979323846;
    $C = 3e8;	    	    	# Velocity of light, m/s
    $ErgPerJoule = 1e7;     	# Ergs per Joule
    $EarthRad = 6378.14;    	# Earth's equatorial radius, km (IAU 1976)
    
    #	Compute volume and mass of impactor from diameter
    
    $r = $Diameter / 2;     	# Radius, metres
    $volume = (4.0 / 3) * $Pi * ($r ** 3);  # Volume, metres^3    
    print("Volume = $volume m^3\n");
    
    $mass = $volume * ($Density * 1000); # Mass, kg
    print("Mass = $mass kg\n");
    
    #	Solve for velocity to achieve required energy
    
    $velocity = sqrt((2 * ($Energy / $ErgPerJoule)) / $mass);
    $cfrac = $velocity / $C;
    print("Velocity = $velocity m/sec, $cfrac c\n");
    if ($cfrac >= 1) {
    	print("BZZZZZT!  Velocity required >= speed of light!\n");
    }
    
    #	Time to traverse Earth diameter at computed speed
    
    $earthtransit = ($EarthRad * 1000 * 2) / $velocity;
    print("Earth crossing time: $earthtransit sec\n");
    
    
