
    #	Trek's End
    
    #	Impactor visibility calculation
    
    #	Having decided on the size of an impactor
    #	(see the accompanying impactor.pl), determine
    #	its approximate visual magnitude for an observer
    #	at a given distance from the object, distance from
    #	the Sun, object albedo, and phase angle (fraction
    #	illuminated).  CAREFUL!  This program expects the
    #	impactor *radius*, not the diameter computed by
    #	impactor.pl--be sure to divide by two before
    #	setting $Req below.
    
    #	The methodology used in this program is explained
    #	in the Web page:
    #	    http://www.sunspot.noao.edu/sunspot/pr/answerbook/magnitude.html
    
    #	If you're looking at this code and don't have
    #	the slightest idea what it's talking about, please
    #	see:
    #
    #	    http://www.fourmilab.ch/documents/treks-end/
    
    #	Designed and implemented by John Walker in July 2003
    #	This program is in the public domain.

    #	Properties of the reflecting body:
    #
    #	    $Req    = Equatorial radius in kilometres
    #	    $Albedo = Fraction of incident light reflected
    #	    	    	(0 = black, 1 = white).
    #	    	    	Venus = 0.65, Earth = 0.367, Moon = 0.12
    #	    	    	Asteroids are generally grouped into
    #	    	    	three classes: dark = 0.06, medium = 0.18,
    #	    	    	and light = 0.40.
    
    #	Observation parameters:
    #
    #	    $R      = Distance from the object from the Sun in AU
    #	    $Delta  = Distance from the object to observer in AU
    #	    $Phi    = Phase angle--when object is completely illuminated,
    #	    	      the phase angle is zero.
    
    # Test case.  Illumination 14.15, Absolute mag 11.65, Apparent mag 1.65
    $Req = 10; $Albedo = 0.1; $R = 1; $Delta = 0.01; $Phi = 0;
    
    #	Trek's End impactor
    $Req = 2.5;  $Albedo = 0.4;  $R = 1;  $Delta = km_to_au(35785);  $Phi = 0;
    
    #	Constants

    $Pi = 3.14159265358979323846;
    $AU = 149597870.0;	    	# Astronomical unit in km
    $SunMag = -26.72;	    	# Apparent magnitude of the Sun at 1 AU
    
    #	Determine illumination at object's distance from the Sun
    $Illumination = $SunMag + 5 * log10($R * $AU);
    printf("Illumination = %.2f\n", $Illumination);
    
    #	Calculate absolute magnitude of object (magnitude when
    #	observed from 1 AU).
    $Vabs = $Illumination - (2.5 * log10(($Req ** 2) * $Albedo));   
    printf("Absolute magnitude: %.2f\n", $Vabs);
    
    #	Compute effect of phase angle on illumination, then
    #	obtain apparent magnitude to observer.
    $fphi = (1 + cos(dtr($Phi))) / 2;
    $Vapp = $Vabs + (5 * log10($R * $Delta)) - (2.5 * log10($fphi));
    printf("Apparent magnitude: %.2f\n", $Vapp);
    
    #	Finally (and this has nothing to do with calculations
    #	above, but is driven by some of the same parameters),
    #	calculate the angle subtended by the object at the
    #	distance from the observer, assuming it is spherical.
    
    $subtends = rtd(asin(($Req * 2) / ($Delta * $AU)));
    $subtendsas = $subtends * 60 * 60;
    printf("Object subtends $subtends ($subtendsas arc seconds)\n");
    
    #	Utility functions
    
    sub asin {	    	    # Arc sin
    	my $x = shift;
	return atan2($x, sqrt(1 - ($x * $x)));
    }
    
    sub log10 {     	    # Log to the base 10
    	my $n = shift;
	return log($n) / log(10);
    }
    
    sub dtr {	    	    # Degrees to radians
    	my $d = shift;
	return ($d * $Pi) / 180;
    }
    
    sub rtd {	    	    # Radians to degrees
    	my $r = shift;
	return ($r * 180) / $Pi;
    }

    sub km_to_au {  	    # Kilometres to astronomical units
    	my $k = shift;
	my $AU = 149597870.0;	# Astronomical unit in km
	return $k / $AU;
    }
